


from colorama import init, Fore, Back, Style

init()

def printer_color(*args, fore, back):
    if len(args) == 1:
        print(fore + str(args[0]) + Style.RESET_ALL)

    if len(args) > 1:
        if "header" in args:
            print("\n"+back + Style.BRIGHT)
            print(fore + "\t" + str(args[0]))
            print(Style.RESET_ALL + "\n")

        if "*" in args:
            print(fore + str(args[0]))
            print(Style.RESET_ALL)

        if "**" in args:
            print("\n"+fore + str(args[0]))
            print(Style.RESET_ALL)


def green(*args): printer_color(*args, fore=Fore.GREEN, back=Back.GREEN)
def white(*args): printer_color(*args, fore=Fore.WHITE, back=Back.WHITE)
def black(*args): printer_color(*args, fore=Fore.BLACK, back=Back.BLACK)
def cyan(*args): printer_color(*args, fore=Fore.CYAN, back=Back.CYAN)
def magenta(*args): printer_color(*args, fore=Fore.MAGENTA, back=Back.MAGENTA)
def red(*args): printer_color(*args, fore=Fore.RED, back=Back.RED)
def blue(*args): printer_color(*args, fore=Fore.BLUE, back=Back.BLUE)
def yellow(*args): printer_color(*args, fore=Fore.YELLOW, back=Back.YELLOW)


def jaimedcsilva(): print("Hello Jaime!")



from distutils.core import setup
setup(
  name = 'jaime38130',
  packages = ['jaime38130'],
  version = '0.5',
  license='-',
  description = 'Colors!',
  author = 'Jaime Silva',
  author_email = 'jaimedcsilva@hotmail.com',
  url = 'https://github.com/JaimeSilva/jaime38130.git',
  download_url = 'https://github.com/JaimeSilva/jaime38130/archive/refs/tags/v_05.tar.gz',
  keywords = ['SOME', 'MEANINGFULL', 'COLORS'],
  install_requires=[
          'colorama',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.10',
  ],
)
